@@ -1,9 +1,9 @@
       block data  epblksepi
-c
+!
 #include  "ZsepManager.h"
       data  IoCont/12/, Ir1/111, 89072411/
       data  StackDiskFileNo/13/
-      data  StackDiskFile/"./stackdisk"/	
+      data  StackDiskFile/"scratch"/
       data  OutPrimaryFileNo/14/
       data  OutPrimaryFile/"./+primaryForLight"/
       end
