@@ -1,10 +1,11 @@
-       subroutine epprmr(dsn)
+      subroutine epprmr(dsn)
+      use modV1ry
        implicit none
 #include  "ZepTrackp.h"
 #include  "ZepManager.h"
-c
-c             read epics file
-c
+!
+!             read epics file
+!
             character*(*) dsn
             integer io,  icon, klena, i
             character*190 msg
@@ -22,7 +23,7 @@ c
                call cerrorMsg('above file not exits', 1)
             endif
 
-c            read baisc parameters; find separater
+!            read baisc parameters; find separater
             call afsep(iowk)
             do while( epgetParmN(iowk, vname, vvalue ) )
                if(vname .eq. 'AngleB') then
@@ -51,6 +52,8 @@ c            read baisc parameters; find separater
                   call arprmr(vvalue, EminH)
                elseif( vname .eq. 'Es' ) then
                   call arprmr(vvalue, Escat)
+               elseif( vname == 'Zcorrec') then
+                  call arprml(vvalue, Zcorrec)
                elseif( vname .eq. 'EupperBndCS') then
                   call arprmr(vvalue, EupperBndCS)
                elseif( vname .eq. 'EpartialSC') then
@@ -87,16 +90,19 @@ c            read baisc parameters; find separater
                   endif
                elseif( vname .eq. 'HowNormBrems') then
                   call arprmi(vvalue, HowNormBrems)
+               elseif( vname .eq. 'HowQuench') then
+                  call arprmi(vvalue, HowQuench)
                elseif( vname .eq. 'IncGp') then
                   write(0,*) 'Sorry: IncGp is managed by param file'
                   write(0,*) 
-     *       'If needed, use HowPhotoP(D=4)in &HPARAM part of param'
+     *       'If needed, use HowPhotoP(D=1)in &HPARAM part of param'
                   stop
                elseif( vname .eq. 'IoTrace') then
                   call arprmi(vvalue, IoTrace)
                elseif( vname .eq. 'Knckon' ) then
                   call arprml(vvalue, Knckon)
-               elseif( vname .eq. 'Molier' ) then
+               elseif( vname .eq. 'Molier' .or.
+     *                 vname == 'Moliere'  ) then  ! v9.170
                   call arprmc(vvalue, msg)
                   if( msg == 't' .or. msg == 'T') then
                      Moliere = 1
@@ -137,6 +143,8 @@ c            read baisc parameters; find separater
                   call arprmr(vvalue, Ezu)
                elseif( vname .eq. 'FreeC' ) then
                   call arprml(vvalue, FreeC)
+               elseif( vname == "FollowV1ry") then
+                  call arprml(vvalue, FollowV1ry)
                elseif( vname .eq. 'EpsLeng') then
                   call arprmr(vvalue, EpsLengX)
                   if(EpsLengX < 0. ) then
@@ -203,7 +211,7 @@ c            read baisc parameters; find separater
      *      dsn(1:klena(dsn))
             call cerrorMsg(msg, 1)
             return
-c      *************
+!      *************
        entry epprmw(io)
             write(io,*)'----------------------'
             call awprml(io,'AngleB', AngleB)
@@ -219,11 +227,13 @@ c      *************
             call awprmc(io, 'ModifyFile', ModifyFile)
             call awprmr(io,'EminH', EminH)
             call awprmr(io,'Es   ', Escat)
+            call awprml(io,'Zcorrec', Zcorrec)
             call awprmr(io,'EupperBndCS ', EupperBndCS)
             call awprmr(io,'EpartialSC ', EpartialSC)
             call awprmi(io,'TargetElecBrems', TargetElecBrems)
             call awprmr(io,'Flpm ', Flpm)
             call awprmi(io,'HowNormBrems', HowNormBrems)
+            call awprmi(io,'HowQuench', HowQuench)
 !            call awprmi(io,'IncGp', IncGp)
             call awprmi(io,'IoTrace', IoTrace)
             call awprml(io,'Knckon', Knckon)
@@ -257,39 +267,42 @@ c      *************
             call awprmc(io, 'TraceDir', TraceDir)
 
       end
-c      ************
+!      ************
        subroutine  epcmp1
-c      ************
+!      ************
        use epModify
        implicit none
 #include "ZepTrackp.h"
 #include "ZepTrackv.h"
 #include "ZepManager.h"
 #include "Zmass.h"
-c             compute something using basic parameters
-c
+!             compute something using basic parameters
+!
        if(ALateCor .eq. 2 .or.
      *        ( ALateCor .eq. 1 .and.  Moliere == 0)) then
-c          angular latelaral correlation will be taken at
-c          multiple scattering. use standard trucation
+!          angular latelaral correlation will be taken at
+!          multiple scattering. use standard trucation
           Tcoefx = Tcoef
           Tminx = Tmin
        else
-c            no correlation will be considered so make
-c          truncation length shorter
+!            no correlation will be considered so make
+!          truncation length shorter
           Tcoefx = Tcoef/2
           Tminx = Tmin/2
        endif
        if(KEmin .eq. 0.) then
-          KEmin = max(EminElec - masele, 20.d-3)  ! 20 MeV
+          KEmin = max(EminElec - masele, 100.d-6)  ! 100 keV
        endif
-       if( EminH == 0. ) then
-          EminH = max( KEmin, 20.d-3)   ! for nutron
+       if( EminH == 0. ) then  ! for neutron
+          EminH = 20.d-3
+       else
+!             use EminH as it is.  Mar. 18, 2014 
+!          EminH = min( EminH, 20.d-3)  
        endif
        if( RecoilKEmin .eq. 0.) then
           RecoilKEmin =EminElec - masele
        endif
-c           save;  to be used in epModify;  in GeV
+!           save;  to be used in epModify;  in GeV
        EminGsave = EminGamma
        EminEsave = EminElec
        RecoilEsave = RecoilKEmin
@@ -301,8 +314,19 @@ c           save;  to be used in epModify;  in GeV
        if( ModifyFile /= " " ) then  ! special modification requested
           call epfixModifier(ModifyFile)
        endif
-c        get info from  Cosmos
+!        get info from  Cosmos
        call epInfoPhotoP( IncGp )
 ! 
 !       call epInfoPhitsJamXs( PhitsXs, JamXs )
        end
+       subroutine epInfoPhotoP(gpinfo)
+   !    if this is placed in epcosIntF.f, epgen must be linked
+   !    which in tern requires ephook. So cannot be used
+   !   from other main.
+   !          copy the info for how to treat photo-had.prog
+   !          from cosmos: HowPhotoP
+      implicit none
+#include "Ztrackp.h"
+      integer,intent(out):: gpinfo
+      gpinfo = HowPhotoP
+      end
